@@ -1,5 +1,5 @@
 /*!
- * froala_editor v1.2.1 (http://editor.froala.com)
+ * froala_editor v1.2.3 (http://editor.froala.com)
  * Copyright 2014-2014 Froala
  */
 
@@ -15,8 +15,8 @@ $.Editable.LANGS['es'] = {
     "Strikethrough": "Tachado",
     "Font Size": "Tama\u00f1o de fuente",
     "Color": "Color",
-    "Background Color": "Color de fondo",
-    "Text Color": "Color del texto",
+    "Background": "Fondo",
+    "Text": "Texto",
     "Format Block": "Formatos",
     "Normal": "Normal",
     "Paragraph": "P\u00e1rrafo",
@@ -51,7 +51,6 @@ $.Editable.LANGS['es'] = {
     "Replace Image": "Reemplazar la imagen",
     "Remove Image": "Quitar la imagen",
     "Title": "T\u00edtulo",
-    "Insert image": "Insertar imagen",
     "Drop image": "Soltar la imagen",
     "or click": "o haga clic en",
     "or": "o",
