@@ -1,5 +1,5 @@
 /*!
- * froala_editor v1.2.1 (http://editor.froala.com)
+ * froala_editor v1.2.3 (http://editor.froala.com)
  * Copyright 2014-2014 Froala
  */
 
@@ -15,8 +15,8 @@ $.Editable.LANGS['fi'] = {
     "Strikethrough": "Yliviivaus",
     "Font Size": "Fonttikoko",
     "Color": "V\u00e4ri",
-    "Background Color": "Taustan v\u00e4ri",
-    "Text Color": "Tekstin v\u00e4ri",
+    "Background": "Taustan",
+    "Text": "Tekstin",
     "Format Block": "Muotoilut",
     "Normal": "Normaali",
     "Paragraph": "Kappale",
@@ -51,7 +51,6 @@ $.Editable.LANGS['fi'] = {
     "Replace Image": "Vaihda kuva",
     "Remove Image": "Poista kuva",
     "Title": "Otsikko",
-    "Insert image": "Lis\u00e4\u00e4 kuva",
     "Drop image": "Pudottaa kuva",
     "or click": "tai napsauta",
     "or": "tai",
