@@ -1,5 +1,5 @@
 /*!
- * froala_editor v1.2.1 (http://editor.froala.com)
+ * froala_editor v1.2.3 (http://editor.froala.com)
  * Copyright 2014-2014 Froala
  */
 
@@ -15,8 +15,8 @@ $.Editable.LANGS['id'] = {
     "Strikethrough": "Coret",
     "Font Size": "Ukuran leter",
     "Color": "Warna",
-    "Background Color": "Warna latar belakang",
-    "Text Color": "Warna teks",
+    "Background": "Latar belakang",
+    "Text": "Teks",
     "Format Block": "Format",
     "Normal": "Normal",
     "Paragraph": "Paragraf",
@@ -51,7 +51,6 @@ $.Editable.LANGS['id'] = {
     "Replace Image": "Mengganti gambar",
     "Remove Image": "Hapus gambar",
     "Title": "Judul",
-    "Insert image": "Memasukkan gambar",
     "Drop image": "Jatuhkan gambar",
     "or click": "atau klik",
     "or": "atau",
