@@ -1,5 +1,5 @@
 /*!
- * froala_editor v1.2.1 (http://editor.froala.com)
+ * froala_editor v1.2.3 (http://editor.froala.com)
  * Copyright 2014-2014 Froala
  */
 
@@ -15,8 +15,8 @@ $.Editable.LANGS['pt_pt'] = {
     "Strikethrough": "Rasurado",
     "Font Size": "Tamanho da fonte",
     "Color": "Cor",
-    "Background Color": "Cor de fundo",
-    "Text Color": "Cor do texto",
+    "Background": "Fundo",
+    "Text": "Texto",
     "Format Block": "Formatos",
     "Normal": "Normal",
     "Paragraph": "Par\u00e1grafo",
@@ -51,7 +51,6 @@ $.Editable.LANGS['pt_pt'] = {
     "Replace Image": "Substituir imagem",
     "Remove Image": "Remover imagem",
     "Title": "T\u00edtulo",
-    "Insert image": "Inserir imagem",
     "Drop image": "Largue imagem",
     "or click": "ou clique em",
     "or": "ou",
